@@ -4,16 +4,14 @@ Main interface for personalize-runtime service.
 Usage::
 
     ```python
-    import boto3
+    from boto3.session import Session
     from mypy_boto3_personalize_runtime import (
         Client,
         PersonalizeRuntimeClient,
     )
 
-    session = boto3.Session()
-
-    client: PersonalizeRuntimeClient = boto3.client("personalize-runtime")
-    session_client: PersonalizeRuntimeClient = session.client("personalize-runtime")
+    session = Session()
+    client: PersonalizeRuntimeClient = session.client("personalize-runtime")
     ```
 """
 from .client import PersonalizeRuntimeClient
