@@ -17,7 +17,11 @@ from typing import Any, Dict, Mapping, Sequence, Type
 
 from botocore.client import BaseClient, ClientMeta
 
-from .type_defs import GetPersonalizedRankingResponseTypeDef, GetRecommendationsResponseTypeDef
+from .type_defs import (
+    GetPersonalizedRankingResponseTypeDef,
+    GetRecommendationsResponseTypeDef,
+    PromotionTypeDef,
+)
 
 __all__ = ("PersonalizeRuntimeClient",)
 
@@ -61,6 +65,14 @@ class PersonalizeRuntimeClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_personalize_runtime/client/#can_paginate)
         """
 
+    def close(self) -> None:
+        """
+        Closes underlying endpoint connections.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/personalize-runtime.html#PersonalizeRuntime.Client.close)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_personalize_runtime/client/#close)
+        """
+
     def generate_presigned_url(
         self,
         ClientMethod: str,
@@ -102,7 +114,8 @@ class PersonalizeRuntimeClient(BaseClient):
         context: Mapping[str, str] = ...,
         filterArn: str = ...,
         filterValues: Mapping[str, str] = ...,
-        recommenderArn: str = ...
+        recommenderArn: str = ...,
+        promotions: Sequence[PromotionTypeDef] = ...
     ) -> GetRecommendationsResponseTypeDef:
         """
         Returns a list of recommended items.
